/** file hotlink.c 
 * This program to test hot linking between a file an GraceGTK
 * To use it:
 *   run GraceGTK with ../ggrace &
 *   Compile with make hotlink
 *   Run ./hotlink
 */

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <unistd.h>

#define RETURN_SUCCESS (0)
#define RETURN_FAILURE (1)

static int fx (const char *fname ,double par ,double x1 ,double x2 ,double step)
{
  FILE *fd;
  double x ,y;
  if ((fd = fopen (fname ,"w")) == 0) return RETURN_FAILURE;
  for (x = x1; x <= x2; x += step) {
      double x1 = x - par;
      y = exp (-par*x1*x1) / par;
      fprintf (fd ,"%f \t %f\n" ,x ,y);
  }
  fclose (fd);
  return RETURN_SUCCESS;
}

int main(int argc, char **argv)
{
  char fname[] = "hotlink.dat";
  double par;

  if (fx (fname ,1.0 ,-5.0 ,8.0 ,0.05) == RETURN_FAILURE) {
    fprintf (stderr ,"Unable to open %s\n" ,fname);
  return EXIT_FAILURE;;
  } else {
    printf ("This program tests hot linking between a file and GraceGTK\n");
    printf ("\n");
    printf ("\tGraceGTK must already be running in the background,\n");
    printf ("\tif not, stop hotlink with Ctrl-C, start \"../src/ggrace &\" and restart hotlink\n");
    printf ("\n");
    printf ("\tImport %s to make a first set\n" ,fname);
    printf ("\tOpen Edit/Hot links... popup\n");
    printf ("\tSelect %s with the Files... button\n" ,fname);
    printf ("\tSelect the set to be linked to this file\n");
    printf ("\tPress the Link button\n");
    printf ("\t   => the link must be displayed in the upper part of the window\n");
    printf ("\n");
    printf ("\tpress return to start the loop into this program\n");
    printf ("\tcomputing a new curve each second\n");
    printf ("and the curve displayed by GraceGTK may be updated by pressing the Update button\n");

    

    getc (stdin);
  }

  for ( par = 1.1; par < 5.0; par += 0.1) {
    fx (fname ,par  ,-5.0 ,8.0 ,0.05);
    printf ("par = %f\n" ,par);
    sleep (1);
  }


  return EXIT_SUCCESS;
}
